Funding
=======
We believe that collaboratively funded software can offer outstanding returns
on investment, by encouraging users to collectively share the cost of
development.

The Eve REST framework continues to be open-source and permissively licensed,
but we firmly believe it is in the commercial best-interest for users of the
project to invest in its ongoing development.

Signing up as a Backer or Sponsor will:

- Directly contribute to faster releases, more features, and higher quality software.
- Allow more time to be invested in documentation, issue triage, and community support.
- Safeguard the future development of the Eve REST framework.

If you run a business and is using Eve in a revenue-generating product, it
would make business sense to sponsor Eve development: it ensures the project
that your product relies on stays healthy and actively maintained. It can also
help your exposure in the Eve community and makes it easier to attract Eve
developers. 

Of course, individual users are also welcome to make a recurring pledge if Eve
has helped you in your work or personal projects. Alternatively, consider
donating as a sign of appreciation - like buying me coffee once in a while :)

Support Eve development
-----------------------
You can support Eve development by pledging on Patreon or donating on PayPal.

- `Become a Backer <https://www.patreon.com/nicolaiarocci>`_ (recurring pledge)
- `Donate via PayPal <https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=7U7G7EWU7EPNW>`_ (one time)


Custom Sponsorship and Consulting
---------------------------------
If you are a business that is building core products using Eve, I am also
open to conversations regarding custom sponsorship / consulting arrangements.
Just `get in touch`_ with me.

.. _`get in touch`: mailto:nicola@nicolaiarocci.com
